Credits
-------


Authors
~~~~~~~

HydrOffice ABC is written and maintained by:

- `Giuseppe Masetti <mailto:gmasetti@ccom.unh.edu>`_


Contributors
~~~~~~~~~~~~

The following wonderful people contributed directly or indirectly to this project:

- `Lachlan Hurst <mailto:lhurst@frontiersi.com.au>`_

Please add yourself here alphabetically when you submit your first pull request.
